export const invoke = 'completer:invoke';

export const invokeNotebook = 'completer:invoke-notebook-1';

export const select = 'completer:select';

export const selectNotebook = 'completer:select-notebook-custom';

export const toggleFlag = 'jupyterlab_mutableai/settings:toggle-flag';

export const updateSettings = 'jupyterlab_mutableai/settings:update-settings';

export const context_fast_forward = 'mutable-ai:prod';

export const context_documentation = 'mutable-ai:doc';

export const context_refactor = 'mutable-ai:refactor';

export const context_custom = 'mutable-ai:custom';
